pub fn projects(models: &[ProjectModel]) -> ValueExpand description
GET /projects: each project with its summary, and the totals the
Dashboard shows.
pub fn projects(models: &[ProjectModel]) -> ValueGET /projects: each project with its summary, and the totals the
Dashboard shows.